Skip to contents

UPDATE: to check if still used. Load a fit. This fit should be saved in a folder that contains a file named fit.rds with the fpemplus object as well as csv files produced by cmdstanr as a result of the estimation process.

Usage

load_fit(path)

Arguments

path

path to the folder containing the model fit

Value

object of class fpemplus