get_standata_routine
Arguments
- routine_data
tibble with iso, year, indicator_name, routine_value, countdownmean routine_value is the value of the routine data (eg coverage) and countdownmean is the data quality indicator for that iso-year-indicator combi needs to be filtered to iso of interest
- fit_routine_obj
brm-fit object
- time_index
from the model fit
- geo_unit_index
from the model fit