UPDATE: to check if still used. Load a fit. This fit should be saved in a folder that contains a file named fit.rds with the fpemplus object as well as csv files produced by cmdstanr as a result of the estimation process.
Source: R/load_fit.R
load_fit.RdUPDATE: to check if still used.
Load a fit. This fit should be saved in a folder that contains
a file named fit.rds with the fpemplus object as well as csv files produced
by cmdstanr as a result of the estimation process.